@@ -668,6 +668,16 @@ class EdgeFunction(
         '''The construct node where permissions are attached.'''
         return typing.cast(aws_cdk.core.ConstructNode, jsii.get(self, "permissionsNode"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceArnsForGrantInvoke")
+    def resource_arns_for_grant_invoke(self) -> typing.List[builtins.str]:
+        '''The ARN(s) to put into the resource field of the generated IAM policy for grantInvoke().
+
+        This property is for cdk modules to consume only. You should not need to use this property.
+        Instead, use grantInvoke() directly.
+        '''
+        return typing.cast(typing.List[builtins.str], jsii.get(self, "resourceArnsForGrantInvoke"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="version")
     def version(self) -> builtins.str:
